@@ -666,6 +666,32 @@ class DataTransformRoot(forms.ModelForm):
         forms = forms + '</div></div>'
         return mark_safe(forms)
 
+    def save(self, commit=True):
+        print('root')
+        print('save: ' + str(self.instance.id))
+        super(DataTransformRoot, self).save(commit)
+        if hasattr(self, 'nested_constants_form') and self.nested_constants_form is not None:
+            self.nested_constants_form.save()
+        if hasattr(self, 'nested_hardware_outputs_form') and self.nested_hardware_outputs_form is not None:
+            self.nested_hardware_outputs_form.save()
+        if hasattr(self, 'nested_hardware_stats_form') and self.nested_hardware_stats_form is not None:
+            self.nested_hardware_stats_form.save()
+        if hasattr(self, 'nested_data_transformer_form') and self.nested_data_transformer_form is not None:
+            self.nested_data_transformer_form.save()
+
+    def save(self, commit=True):
+        print('root')
+        print('save: ' + str(self.instance.id))
+        super(DataTransformRoot, self).save(commit)
+        if hasattr(self, 'nested_constants_form') and self.nested_constants_form is not None:
+            self.nested_constants_form.save()
+        if hasattr(self, 'nested_hardware_outputs_form') and self.nested_hardware_outputs_form is not None:
+            self.nested_hardware_outputs_form.save()
+        if hasattr(self, 'nested_hardware_stats_form') and self.nested_hardware_stats_form is not None:
+            self.nested_hardware_stats_form.save()
+        if hasattr(self, 'nested_data_transformer_form') and self.nested_data_transformer_form is not None:
+            self.nested_data_transformer_form.save()
+
     class Meta:
         model = DataTransformer
         fields = ['id', 'accessory', 'type']
