@@ -363,7 +363,7 @@ class HardwareViewSet(viewsets.ModelViewSet):
             return HttpResponse(render(request, 'hardwares.html'))
 
 
-from data.forms.forms import  DataTransform, DataTransformRoot
+from data.forms.forms import DataTransform, DataTransformRoot
 from data.models.models import DataTransformer
 
 
@@ -431,21 +431,17 @@ class AccessoryViewSet(viewsets.ModelViewSet):
         return JsonResponse({"error": ""}, status=400)
 
     def postDataTransformer(request):
+        print('post data transformer')
         # request should be ajax and method should be POST.
-        if request.is_ajax and request.method == "POST":
-            form = DataTransformRoot(request.POST)
-            if form.is_valid():
-                instance = form.save()
-                print(str(instance))
-                # serialize in new friend object in json
-                ser_instance = django_serializers.serialize('json', [instance, ])
-                print(str(ser_instance))
-                # send to client side.
-                return JsonResponse({"instance": ser_instance}, status=200)
-            else:
-                # some form errors occured.
-                return JsonResponse({"error": form.errors}, status=400)
-        return JsonResponse({"error": ""}, status=400)
+        form = DataTransformRoot(request.POST)
+        instance = form.save()
+        print(str(instance))
+        # serialize in new friend object in json
+        ser_instance = django_serializers.serialize('json', [instance, ])
+        print(str(ser_instance))
+        # send to client side.
+        return JsonResponse({"instance": ser_instance}, status=200)
+
 
     def postCalibration(request):
         print('post calibration')
